/*
 * File name: reduce.h
 * Date:      2015/01/09 10:50
 * Author:    Michal Burda
 */


#ifndef __LFL__REDUCE_H__
#define __LFL__REDUCE_H__


#include <common.h>
#include "Rcpp.h"


RcppExport SEXP reduceCpp(SEXP aConfig);


#endif
